/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2017 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.stamkort.util;

import java.time.Instant;
import java.util.UUID;

public class ProxyData {
    private UserType userType;
    private String requestId;
    private Instant requestTimestamp;
    private String messageId;
    private String flowId;
    private String soapAction;
    private String idCardID;
    private String idCardIssuer;
    private String idCardVersion;
    private String authenticationLevel;
    private String cprnr;
    private String givenName;
    private String surName;
    private String emailAddress;
    private String role;
    private String authorizationCode;
    private String educationCode;
    private String occupation;
    private String itSystemName;
    private String careProviderID;
    private String careProviderName;
    private String careProviderType;

    public ProxyData(UserType userType) {
        this.userType = userType;
        this.requestId = UUID.randomUUID().toString();
        this.requestTimestamp = Instant.now();
    }

    public String getRequestId() {
        return requestId;
    }

    public void setRequestId(String requestId) {
        this.requestId = requestId;
    }

    public Instant getRequestTimestamp() {
        return requestTimestamp;
    }

    public void setRequestTimestamp(Instant requestTimestamp) {
        this.requestTimestamp = requestTimestamp;
    }

    public String getMessageId() {
        return messageId;
    }

    public void setMessageId(String messageId) {
        this.messageId = messageId;
    }

    public String getFlowId() {
        return flowId;
    }

    public void setFlowId(String flowId) {
        this.flowId = flowId;
    }

    public String getSoapAction() {
        return soapAction;
    }

    public void setSoapAction(String soapAction) {
        this.soapAction = soapAction;
    }

    public String getIdCardID() {
        return idCardID;
    }

    public void setIdCardID(String idCardID) {
        this.idCardID = idCardID;
    }

    public String getIdCardIssuer() {
        return idCardIssuer;
    }

    public void setIdCardIssuer(String idCardIssuer) {
        this.idCardIssuer = idCardIssuer;
    }

    public String getIdCardVersion() {
        return idCardVersion;
    }

    public void setIdCardVersion(String idCardVersion) {
        this.idCardVersion = idCardVersion;
    }

    public String getAuthenticationLevel() {
        return authenticationLevel;
    }

    public void setAuthenticationLevel(String authenticationLevel) {
        this.authenticationLevel = authenticationLevel;
    }

    public String getCprnr() {
        return cprnr;
    }

    public void setCprnr(String cprnr) {
        this.cprnr = cprnr;
    }

    public String getGivenName() {
        return givenName;
    }

    public void setGivenName(String givenName) {
        this.givenName = givenName;
    }

    public String getSurName() {
        return surName;
    }

    public void setSurName(String surName) {
        this.surName = surName;
    }

    public String getEmailAddress() {
        return emailAddress;
    }

    public void setEmailAddress(String emailAddress) {
        this.emailAddress = emailAddress;
    }

    public String getRole() {
        return role;
    }

    public void setRole(String role) {
        this.role = role;
    }

    public String getAuthorizationCode() {
        return authorizationCode;
    }

    public void setAuthorizationCode(String authorizationCode) {
        this.authorizationCode = authorizationCode;
    }

    public String getEducationCode() {
        return educationCode;
    }

    public void setEducationCode(String educationCode) {
        this.educationCode = educationCode;
    }

    public String getOccupation() {
        return occupation;
    }

    public void setOccupation(String occupation) {
        this.occupation = occupation;
    }

    public String getItSystemName() {
        return itSystemName;
    }

    public void setItSystemName(String itSystemName) {
        this.itSystemName = itSystemName;
    }

    public String getCareProviderID() {
        return careProviderID;
    }

    public void setCareProviderID(String careProviderID) {
        this.careProviderID = careProviderID;
    }

    public String getCareProviderName() {
        return careProviderName;
    }

    public void setCareProviderName(String careProviderName) {
        this.careProviderName = careProviderName;
    }

    public String getCareProviderType() {
        return careProviderType;
    }

    public void setCareProviderType(String careProviderType) {
        this.careProviderType = careProviderType;
    }

    public UserType getUserType() {
        return userType;
    }

    public enum UserType {
        HealthCareProfessional,
        Citizen,
        SystemUser
    }
}
