/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2017 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.stamkort.util.configuration;

import dk.stamkort.util.dgws.DgwsNspUserHandler;
import dk.stamkort.util.dgws.DgwsSoapDecorator;
import dk.stamkort.util.dgws.STSRequestHelper;
import dk.sundhedsdatastyrelsen.fsk._2020._07._28.PersonalDataCardPortType;
import dk.sundhedsdatastyrelsen.fsk._2020._07._28.PersonalDataCardService;
import org.apache.cxf.endpoint.Client;
import org.apache.cxf.frontend.ClientProxy;
import org.apache.cxf.interceptor.Interceptor;
import org.apache.cxf.interceptor.LoggingInInterceptor;
import org.apache.cxf.interceptor.LoggingOutInterceptor;

import javax.xml.ws.BindingProvider;

public class Configuration {
    public PersonalDataCardPortType createSkrClient(String endpoint) {
        PersonalDataCardService s = new PersonalDataCardService();
        PersonalDataCardPortType port = s.getPersonalDataCardPort();
        BindingProvider bindingProvider = (BindingProvider) port;
        bindingProvider.getRequestContext().put(BindingProvider.ENDPOINT_ADDRESS_PROPERTY, endpoint);

        Client client = ClientProxy.getClient(port);
        client.getInInterceptors().add(new LoggingInInterceptor());
        client.getOutInterceptors().add(new LoggingOutInterceptor());
        client.getOutInterceptors().add(dgwsMocesNspUserHandler());

        return port;
    }

    private Interceptor dgwsSoapDecorator() {
        DgwsNspUserHandler dgwsNspUserHandler = new DgwsNspUserHandler(new STSRequestHelper());
        dgwsNspUserHandler.setHealthCareProfessionalVoces();
        return new DgwsSoapDecorator(dgwsNspUserHandler);
    }

    private Interceptor dgwsMocesNspUserHandler() {
        DgwsNspUserHandler dgwsNspUserHandler = new DgwsNspUserHandler(new STSRequestHelper());
        dgwsNspUserHandler.setHealthCareProfessionalMoces();
        return new DgwsSoapDecorator(dgwsNspUserHandler);
    }

}
