/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2017 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.stamkort.util.dgws;

import dk.sosi.seal.model.CareProvider;
import dk.sosi.seal.model.constants.SubjectIdentifierTypeValues;
import org.springframework.core.io.ClassPathResource;
import org.springframework.core.io.Resource;

import java.io.IOException;

public class DgwsNspUserHandler {

    private static final String CPR = "2708599967";
    private static final boolean CONSENT_OVERRIDE = false;
    private static final String SSI_CVR_NUMBER = "46837428";
    private static final String SSI = "Statens Serum Institut";
    private static final String LAKESIDE_CVR_NUMBER = "25450442";
    private static final String LAKESIDE_A_S = "LAKESIDE A/S";
    private STSRequestHelper stsRequestHelper;

    private DgwsNspUserContext userContext;

    public DgwsNspUserHandler(STSRequestHelper stsRequestHelper){
        this.stsRequestHelper = stsRequestHelper;
    }

    public DgwsNspUserContext getNspUserContext() {
        return userContext;
    }

    public void setNspUserContext(DgwsNspUserContext user) {
        this.userContext = user;
    }

    public void clearNspUserContext() {
        this.userContext = null;
    }


    public void setHealthCareProfessionalVoces() {
        DgwsNspUserContext userContext = createHealthCareProfessionalVoces();
        setNspUserContext(userContext);
    }

    public void setHealthCareProfessionalMoces() {
        DgwsNspUserContext userContext = createHealthCareProfessionalMoces();
        setNspUserContext(userContext);
    }

    private DgwsNspUserContext createHealthCareProfessionalMoces() {
        Resource keystore = new ClassPathResource("/Sonja_Bach_Laege.jks");
        String password = "Test1234";
        String alias = "sosi:alias_system";
        String patientId = "2708599967";
        String userCivilRegistrationNumber = "0309691444";
        String userAuthCode = "NS363";
        String userGivenName = "Sonja";
        String userSurName = "Bach";
        String userEmail = "sonja@sonja";
        String userOccupation = "Læge";
        String userOrganizationCode = "1000988772";

        CareProvider careProvider = new CareProvider(SubjectIdentifierTypeValues.CVR_NUMBER, SSI_CVR_NUMBER, LAKESIDE_A_S);

        try {
            HealthCareProfessionalMocesContext hpm = new HealthCareProfessionalMocesContext(stsRequestHelper, keystore, password, alias, CPR, userCivilRegistrationNumber, userAuthCode, userGivenName, userSurName, userEmail, userOccupation, userAuthCode, careProvider, CONSENT_OVERRIDE);
            return hpm;
        } catch (IOException e) {
            throw new RuntimeException(e);
        }
    }

    private DgwsNspUserContext createHealthCareProfessionalVoces() {
        Resource keystore = new ClassPathResource("/Statens_Serum_Institut_VOCES.jks");
        String password = "Test1234";
        String alias = "sosi:alias_system";
        String userCivilRegistrationNumber = "0804569723";
        String userAuthCode = "CBNH1";
        String userGivenName = "Casper";
        String userSurName = "Rasmussen";
        String userEmail = "casper56@hotdocs.dk";
        String userOccupation = "Læge";
        String userOrganizationCode = "1000988772";
        CareProvider careProvider = new CareProvider(SubjectIdentifierTypeValues.CVR_NUMBER, SSI_CVR_NUMBER, SSI);

        try {
            HealthCareProfessionalVocesContext hpm = new HealthCareProfessionalVocesContext(stsRequestHelper, keystore, password, alias, CPR, userCivilRegistrationNumber, userAuthCode, userGivenName, userSurName, userEmail, userOccupation, userOrganizationCode, careProvider, CONSENT_OVERRIDE);
            return hpm;
        } catch (IOException e) {
            throw new RuntimeException(e);
        }
    }
}
