/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2017 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.stamkort.util.dgws;

import dk.sosi.seal.model.Request;
import org.apache.cxf.binding.soap.SoapMessage;
import org.apache.cxf.binding.soap.interceptor.AbstractSoapInterceptor;
import org.apache.cxf.headers.Header;
import org.apache.cxf.interceptor.Fault;
import org.apache.cxf.phase.Phase;
import org.w3c.dom.Document;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;

import javax.xml.namespace.QName;
import java.io.IOException;

public class DgwsSoapDecorator extends AbstractSoapInterceptor {
    private DgwsNspUserHandler dgwsNspUserHandler;

    public DgwsSoapDecorator(DgwsNspUserHandler dgwsNspUserHandler) {
        super(Phase.PRE_STREAM);
        this.dgwsNspUserHandler = dgwsNspUserHandler;
    }

    @Override
    public void handleMessage(SoapMessage message) throws Fault {
        try {
            // Add the DGWS headers
            Document sosi = getSosiDocument();
            NodeList children = sosi.getDocumentElement().getFirstChild().getChildNodes();
            for (int i = 0; i < children.getLength(); i++) {
                Node element = children.item(i);
                QName qname = new QName(element.getNamespaceURI(), element.getLocalName());
                Header dgwsHeader = new Header(qname, element);
                message.getHeaders().add(dgwsHeader);
            }

        } catch (IOException e) {
            throw new Fault(e);
        }
    }

    private Document getSosiDocument() throws IOException {
        Request request = dgwsNspUserHandler.getNspUserContext().getSosiFactory().createNewRequest(false, null);
        request.setIDCard(dgwsNspUserHandler.getNspUserContext().getToken());

        return request.serialize2DOMDocument();
    }


    public DgwsNspUserHandler getUserHandler() {
        return dgwsNspUserHandler;
    }
}