/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2017 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.stamkort.dgws;

import dk.sosi.seal.SOSIFactory;
import dk.sosi.seal.model.*;
import dk.sosi.seal.model.constants.SubjectIdentifierTypeValues;
import org.springframework.core.io.ClassPathResource;
import org.springframework.core.io.Resource;

import java.io.IOException;

public class UserIdCardHelper extends DgwsNspSosiIdCardHelper {

    private CareProvider careProvider;
    
    private UserInfo userInfo;
    
    
    public static UserIdCardHelper createUserIdCardHelper() {
        Resource keystore = new ClassPathResource("/validMocesVault.jks");
        String password = "Test1234";
        String alias = "sosi:alias_system";
        String userCivilRegistrationNumber = "0501792275";
        String userAuthCode = "J0184";
        String userGivenName = "Lars";
        String userSurName = "Larsen";
        String userEmail = "ll@trifork.com";
        String userOccupation = "Laege";
        String userOrganizationCode = "1000988772";
        //CareProvider careProvider = new CareProvider(SubjectIdentifierTypeValues.CVR_NUMBER, LAKESIDE_CVR_NUMBER, LAKESIDE_A_S);
        CareProvider careProvider = new CareProvider("medcom:cvrnumber", "20921897", "Trifork");
        UserInfo userInfo = new UserInfo(userCivilRegistrationNumber, userGivenName, userSurName, userEmail, userOccupation, userOrganizationCode, userAuthCode);

        try {
            UserIdCardHelper hpm = new UserIdCardHelper(keystore, password, alias, userInfo, careProvider);
            return hpm;
        } catch (IOException e) {
            throw new RuntimeException(e);
        }
    }

    
    public UserIdCardHelper(Resource keystore, String password, String alias, UserInfo userInfo, CareProvider careProvider) throws IOException {
        super(keystore, password, alias);
        this.careProvider = careProvider;
        this.userInfo = userInfo;
    }


    @Override
    public SystemIDCard createNewIdCard(SOSIFactory sosi) {
        UserIDCard selfSignedUserIdCard = sosi.createNewUserIDCard("Test", this.userInfo, this.careProvider, AuthenticationLevel.MOCES_TRUSTED_USER, null, null, x509.getCertificate(), null);
        return selfSignedUserIdCard;
    }
}
